@@ -1,18 +1,7 @@
 /*
- Copyright 2015 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+    SPDX-FileCopyrightText: 2015 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either
- version 2.1 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "purpose/configuration.h"
@@ -71,13 +60,13 @@ public:
             KPluginFactory* factory = loader.factory();
             if (!factory) {
                 qWarning() << "Couldn't create job:" << fileName << loader.errorString();
-                return Q_NULLPTR;
+                return nullptr;
             }
             Purpose::PluginBase* plugin = dynamic_cast<Purpose::PluginBase*>(factory->create<QObject>(parent, QVariantList()));
 
             if (!plugin) {
                 qWarning() << "Couldn't load plugin:" << fileName << loader.errorString();
-                return Q_NULLPTR;
+                return nullptr;
             }
 
             return plugin->createJob();
@@ -121,7 +110,8 @@ bool Configuration::isReady() const
 {
     Q_D(const Configuration);
     bool ok = true;
-    Q_FOREACH(const QJsonValue& arg, neededArguments()) {
+    const auto arguments = neededArguments();
+    for (const QJsonValue& arg : arguments) {
         if(!d->m_inputData.contains(arg.toString())) {
             qDebug() << "missing mandatory argument" << arg.toString();
             ok = false;
@@ -134,8 +124,8 @@ QJsonArray Configuration::neededArguments() const
 {
     Q_D(const Configuration);
     QJsonArray ret = d->m_pluginType.value(QStringLiteral("X-Purpose-InboundArguments")).toArray();
-    QJsonArray arr = d->m_pluginData.rawData().value(QStringLiteral("X-Purpose-Configuration")).toArray();
-    Q_FOREACH(const QJsonValue &val, arr)
+    const QJsonArray arr = d->m_pluginData.rawData().value(QStringLiteral("X-Purpose-Configuration")).toArray();
+    for (const QJsonValue &val : arr)
         ret += val;
     return ret;
 }
@@ -143,7 +133,7 @@ QJsonArray Configuration::neededArguments() const
 Purpose::Job* Configuration::createJob()
 {
     if (!isReady())
-        return Q_NULLPTR;
+        return nullptr;
 
     Q_D(const Configuration);
 
@@ -155,7 +145,7 @@ Purpose::Job* Configuration::createJob()
     job->setProperty("outputArgs", d->m_pluginType.value(QStringLiteral("X-Purpose-OutboundArguments")));
 
     connect(job, &Purpose::Job::finished, &ConfigurationPrivate::checkJobFinish);
-    connect(job, &Purpose::Job::finished, this, &QObject::deleteLater);
+    connect(job, &QObject::destroyed, this, &QObject::deleteLater);
     return job;
 }
 
@@ -186,3 +176,16 @@ void Configuration::setUseSeparateProcess(bool use)
     Q_D(Configuration);
     d->m_useSeparateProcess = use;
 }
+
+QString Configuration::pluginTypeName() const
+{
+    Q_D(const Configuration);
+    KPluginMetaData md(d->m_pluginType, {});
+    return md.name();
+}
+
+QString Configuration::pluginName() const
+{
+    Q_D(const Configuration);
+    return d->m_pluginData.name();
+}
