@@ -1,18 +1,7 @@
 /*
- Copyright 2015 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+    SPDX-FileCopyrightText: 2015 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either
- version 2.1 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public
- License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include <QApplication>
@@ -90,12 +79,7 @@ public:
 
 private Q_SLOTS:
     void error() {
-#if (QT_VERSION <= QT_VERSION_CHECK(5, 15, 0))
-        const auto socketError = m_socket.error();
-#else
-        const auto socketError = m_socket.socketError();
-#endif
-        qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "socket error:" << socketError;
+        qCWarning(PURPOSE_EXTERNAL_PROCESS_LOG) << "socket error:" << m_socket.error();
     }
 
     void propertyChanged() {
