@@ -1,29 +1,15 @@
 /*
- Copyright 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+    SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 
- This library is free software; you can redistribute it and/or
- modify it under the terms of the GNU Lesser General Public
- License as published by the Free Software Foundation; either 
- version 2.1 of the License, or (at your option) any later version.
-
- This library is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- Lesser General Public License for more details.
-
- You should have received a copy of the GNU Lesser General Public 
- License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include <purpose/job.h>
 #include <purpose/pluginbase.h>
 
 #include <KLocalizedString>
-#include <QDebug>
-#include <QTimer>
 #include <QStandardPaths>
 #include <QFile>
-#include <QJsonDocument>
 #include <QJsonArray>
 #include <QFileInfo>
 #include <KPluginFactory>
@@ -51,9 +37,9 @@ class SaveAsShareJob : public Purpose::Job
             setCapabilities(Killable | Suspendable);
         }
 
-        virtual void start() override
+        void start() override
         {
-            QJsonArray inputUrls = data().value(QStringLiteral("urls")).toArray();
+            const QJsonArray inputUrls = data().value(QStringLiteral("urls")).toArray();
 
             if (inputUrls.isEmpty()) {
                 setErrorText(i18n("No URLs to save"));
@@ -64,7 +50,7 @@ class SaveAsShareJob : public Purpose::Job
 
             QList<QUrl> urls;
             bool containsData = false;
-            foreach(const QJsonValue &val, inputUrls) {
+            for (const QJsonValue &val : inputUrls) {
                 urls.append(QUrl(val.toString()));
                 containsData |= urls.last().scheme() == QLatin1String("data");
             }
@@ -116,12 +102,12 @@ class Q_DECL_EXPORT SaveAsPlugin : public Purpose::PluginBase
     public:
         SaveAsPlugin(QObject* p, const QVariantList& ) : Purpose::PluginBase(p) {}
 
-        virtual Purpose::Job* createJob() const override
+        Purpose::Job* createJob() const override
         {
             return new SaveAsShareJob(nullptr);
         }
 };
 
-K_PLUGIN_FACTORY_WITH_JSON(SaveAsShare, "saveasplugin.json", registerPlugin<SaveAsPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SaveAsPlugin, "saveasplugin.json")
 
 #include "saveasplugin.moc"
